@@ -1,10 +1,8 @@
 package DateTime::Calendar::Pataphysical;
-
+$DateTime::Calendar::Pataphysical::VERSION = '0.05';
 use strict;
-
-use vars qw($VERSION);
-
-$VERSION = '0.04';
+use warnings;
+use utf8;
 
 use DateTime::Duration;
 use DateTime::Locale;
@@ -118,7 +116,7 @@ sub is_leap_year {
 sub year    { $_[0]->{year} }
 
 sub month   { $_[0]->{month} }
-*mon = \&month;          
+*mon = \&month;
 
 sub month_0 { $_[0]->{month}-1 }
 *mon_0 = \&month_0;
@@ -132,7 +130,7 @@ sub day_of_month_0 { $_[0]->{day} - 1 }
 *mday_0 = \&day_of_month_0;
 
 sub month_name {
-    return (qw/Absolu Haha As Sable Dcervelage Gueules Pdale Clinamen
+    return (qw/Absolu Haha As Sable Décervelage Gueules Pédale Clinamen
                Palotin Merdre Gidouille Tatane Phalle/)[$_[0]->{month}-1];
 }
 
@@ -161,11 +159,11 @@ sub day_name {
 
     if ($self->{day} == 29) {
         my $name = 'hunyadi';
-        my $n = $self->{locale}->day_names->[0];
+        my $n = $self->{locale}->day_format_wide->[0];
         $name = ucfirst $name if $n eq ucfirst $n;
         return $name;
     } else {
-        return $self->{locale}->day_names->[($self->day_of_week_0 || 7)-1];
+        return $self->{locale}->day_format_wide->[($self->day_of_week_0 || 7)-1];
     }
 }
 
@@ -180,7 +178,7 @@ sub week_number {
 }
 
 sub week_year { $_[0]->year }
-    
+
 sub week { $_[0]->week_year, $_[0]->week_number }
 
 sub day_of_year {
@@ -396,7 +394,7 @@ sub from_epoch {
                     );
 
     my $rd = int($p{epoch}/(24*60*60) + 719163);
-    
+
     my ($y, $m, $d) = $class->_rd2ymd( $rd );
 
     return $class->new( year => $y, month => $m, day => $d,
@@ -472,9 +470,9 @@ sub subtract_datetime {
 
 use constant INFINITY     =>       100 ** 100 ** 100 ;
 use constant NEG_INFINITY => -1 * (100 ** 100 ** 100);
-            
+
 sub _compare_overload
-{       
+{
     # note: $_[1]->compare( $_[0] ) is an error when $_[1] is not a
     # DateTime (such as the INFINITY value)
     return $_[2] ? - $_[0]->compare( $_[1] ) : $_[0]->compare( $_[1] );
@@ -510,75 +508,75 @@ sub type_of_feast {
 # Feasts from
 # http://perso.wanadoo.fr/mexiqueculture/nouvelles6-latumba.htm
 @feasts = map [/(.) (.+)/], split /\n+/, <<EOF;
-1 Nativit d'Alfred Jarry
+1 Nativité d'Alfred Jarry
 4 St Ptyx, silentiaire (Abolition de)
-4 St Phnix, solipsiste et St Hyx, factotum
+4 St Phénix, solipsiste et St Hyx, factotum
 4 St Lucien de Samosate, voyageur
 4 St Bardamu, voyageur
-4 Ste Vrola, assistante sociale
+4 Ste Vérola, assistante sociale
 4 St Alambic, abstracteur
 3 Absinthe, ci-devant St Alfred
 4 Descente du St Esprit (de Vin)
 v Dilution
-4 Ste Pure, sportswoman
+4 Ste Purée, sportswoman
 v Vide
 4 St Canterel, l'illuminateur
-4 St Sophrotatos l'Armnien, pataphysicien
-3 thernit
-4 St Ibicrate le Gomtre, pataphysicien
-v Cphalorgie
-v Fltes de Pan
+4 St Sophrotatos l'Arménien, pataphysicien
+3 Éthernité
+4 St Ibicrate le Géomètre, pataphysicien
+v Céphalorgie
+v Flûtes de Pan
 4 Stes Grues, ophiophiles
-4 Ste Mlusine, souillarde de cuisine
+4 Ste Mélusine, souillarde de cuisine
 4 St Venceslas, duc
 2 Emmanuel Dieu
 4 Ste Varia-Miriam, amphibie
-4 Sts Rakirs et Rastrons, porte-ctelettes
-4 Nativit de Sa Magnificence Opach
-4 St Joseb, notaire  la mode de Bretagne
+4 Sts Rakirs et Rastrons, porte-côtelettes
+4 Nativité de Sa Magnificence Opach
+4 St Joseb, notaire à la mode de Bretagne
 4 Stes Gigolette et Gaufrette, dogaresses
 v Xylostomie
 v Le Jet Musical
 
-2 L'ge du Dr Faustroll
+2 L'Âge du Dr Faustroll
 4 Dissolution d'E. Poe, dinomythurge
-4 St Gibus, franc-maon
-4 Ste Berthe de Courrire, grie
+4 St Gibus, franc-maçon
+4 Ste Berthe de Courrière, égérie
 4 Ste Belgique, nourrice
-4 Ste Tourte, lyrique et Ste Bvue, sociologue
-4 St Prout, abb
-2 Fte du Haha
+4 Ste Tourte, lyrique et Ste Bévue, sociologue
+4 St Prout, abbé
+2 Fête du Haha
 v Tautologie
 4 St Panmuphle, huissier
 4 Sortie de St L. Cranach, apocalypticien
 4 St Cosinus, savant
 4 Bse Fenouillard, sainte famille
 4 Exhibition de la Daromphe
-3 Nativit de l'OEstre, artificier
-4 Ste Vadrouille, emblme
+3 Nativité de l'Œstre, artificier
+4 Ste Vadrouille, emblème
 4 St Homais d'Aquin, prudhomme
-4 Nativit de Sa Magnificence le baron Mollet (St Pipe)
-4 St Raphal, apritif et philistin
+4 Nativité de Sa Magnificence le baron Mollet (St Pipe)
+4 St Raphaël, apéritif et philistin
 3 Strangulation de Bosse-de-Nage
 3 Zimzoum de Bosse-de-Nage
-2 Rsurrection de Bosse-de-Nage
+2 Résurrection de Bosse-de-Nage
 3 Chapeau de Bosse-de-Nage
 4 St Cl. Terrasse, musicien des Phynances
 4 St J.-P. Brisset, philologue, prince des penseurs
-4 Commmoration du Cure-dent
+4 Commémoration du Cure-dent
 1 Occultation d'Alfred Jarry
 4 Fuite d'Ablou
-v Mare Terrestre
+v Marée Terrestre
 
-3 Nativit de Pantagruel
-4 Ste Rrose Slavy, hrone
+3 Nativité de Pantagruel
+4 Ste Rrose Sélavy, héroïne
 4 Couronnement de Lord Patchogue, miroitier
 4 St Cravan, boxeur
 4 St Van Meegeren, faussaire
 4 St Omnibus, satyre
 4 St Cyrano de Bergerac, explorateur
 3 St Rimbe, oisif
-v quarrissage pour tous
+v Équarrissage pour tous
 4 St Abstrait, bourreau
 4 St Ossian, barde postiche
 3 Dispute du Signe + et du Signe -
@@ -588,43 +586,43 @@ v quarrissage pour tous
 4 St Cap, captain
 4 St Pangloss, humoriste passif
 4 St Chambernac, pauvriseur
-4 St Courtial des Preires, arostier et inventeur
+4 St Courtial des Péreires, aérostier et inventeur
 4 St Olibrius, augure
-4 St Possible, schizophrne
-2 St Lautramont
+4 St Possible, schizophrène
+2 St Lautréamont
 4 St Quincey, critique d'art
 4 St Berbiguier, martyr
 4 St Lewis Carroll, professeur
-4 St Mensonger, vque
-4 Ste Visit, fille du prcdent
-4 Nativit de St Swift, chanoine
-v Traverse du Miroir
+4 St Mensonger, évêque
+4 Ste Visité, fille du précédent
+4 Nativité de St Swift, chanoine
+v Traversée du Miroir
 
 3 Noces de Balkis et de Salomon
-4 St Doublemain, idologue
+4 St Doublemain, idéologue
 4 St Phlegmon, doctrinaire
-4 Ste Barbe (femme ), femme-canon
+4 Ste Barbe (femme à), femme-canon
 4 Ste Savate, avocate
 4 St Navet et Ste Perruque, humanistes
 4 St Birbe, juge
 2 Conception du P. Ubu (A. J.)
-4 St Sagouin, homme d'tat
+4 St Sagouin, homme d'état
 1 Exaltation d'Ubu Roi (Ubu d'hiver)
-4 Nativit de St Grabbe, scherziste
-4 Ste Choupe, mre de famille
+4 Nativité de St Grabbe, scherziste
+4 Ste Choupe, mère de famille
 4 St Flaive, concierge
 4 Don Quichotte, champion du monde
 2 Khurmookum du Dr Faustroll
 4 St Nul, exempt
-4 St Moyen, franais
+4 St Moyen, français
 4 Ste Lurette, joconde
-3 Gravidit de Mre Ubu
+3 Gravidité de Mère Ubu
 4 St Sabre, allopathe
 4 Ste Tape, pompette
-1 Csar - Antechrist
+1 César - Antechrist
 4 Ste Viole, vierge et martyre
-4 Ste Pochete, gouvernante
-3 Nativit de l'Archoptryx
+4 Ste Pochetée, gouvernante
+3 Nativité de l'Archéoptéryx
 4 Monsieur Sisyphe
 4 St Tic, conjoint
 4 St Cervelas, penseur
@@ -633,25 +631,25 @@ v Aleph
 3 St Alaodine, virtuose
 4 Sts Hassassins, praticiens
 4 Astu
-1 Dcervelage
+1 Décervelage
 4 Sts Giron, Pile et Cotice, palotins
-4 Sts Polonais, proltaires
-4 Sts Forats, poliorctes
+4 Sts Polonais, prolétaires
+4 Sts Forçats, poliorcètes
 3 St Bordure, capitaine
-4 Dormition de Jacques Vach, interprte
-v Drapaud (rection du)
-4 St Eustache, librateur
-4 St Landru, gyncologue
-4 St Guillotin, mdecin
+4 Dormition de Jacques Vaché, interprète
+v Drapaud (érection du)
+4 St Eustache, libérateur
+4 St Landru, gynécologue
+4 St Guillotin, médecin
 4 Sts 4 Sans-Cou, enchanteurs
 3 Conscience d'Ubu
 4 St Mauvais, sujet
-4 St Mandrin, pote et philosophe
+4 St Mandrin, poète et philosophe
 4 Sts Pirates et Flibustiers, thaumaturges
-4 St et Ste Cartouche, vtrinaires
+4 St et Ste Cartouche, vétérinaires
 4 St Outlaw, aristocrate
-1 Chaire du Dr FaustrolL
-2 Ostention du Bton  Physique
+1 Chaire du Dr Faustroll
+2 Ostention du Bâton à Physique
 4 St Tank, animal
 4 St Weidman, patriarche
 4 St Petiot, expert
@@ -660,245 +658,245 @@ v Escrime
 v Repopulation
 v Lit de Procruste
 
-3 Dpucelage de Mre Ubu
-4 St Sigisbe, eunuque
-4 St Anthropode, policier
+3 Dépucelage de Mère Ubu
+4 St Sigisbée, eunuque
+4 St Anthropoïde, policier
 4 Ste Goule ou Gudule, institutrice
 4 Ste Gale, abbesse
 4 Ste Touche, postulante
-4 St Gueule, abb
-3 Fte de la Chandelle Verte
-4 Ste Crpe, laque
-4 St Prservatif, bedeau
-4 St Baobab, clibataire
+4 St Gueule, abbé
+3 Fête de la Chandelle Verte
+4 Ste Crêpe, laïque
+4 St Préservatif, bedeau
+4 St Baobab, célibataire
 4 St Membre, compilateur
 v Copulation
-4 Nativit de St J. Verne, globe-trotter en chambre
-v Alice au Pays des Merveilles
-4 St Mnchhausen, baron
-4 Le Btrou, thurge
-4 Nativit de St Deibler, prestidigitateur
-4 St Sade s liens
+4 Nativité de St J. Verne, globe-trotter en chambre
+3 Alice au Pays des Merveilles
+4 St Münchhausen, baron
+4 Le Bétrou, théurge
+4 Nativité de St Deibler, prestidigitateur
+4 St Sade ès liens
 4 St Lafleur, valet
 v Lavement
 2 St Sexe, stylite
 4 Occultation de St J. Torma, euphoriste
 4 Conversion de St Matorel, bateleur
-4 Ste Marmelade, inspire
+4 Ste Marmelade, inspirée
 3 L'Amour Absolu, deliquium
-4 Ste Tabagie, cosmogne
+4 Ste Tabagie, cosmogène
 4 Sts Hylactor et Pamphagus
-v Mouvement Perptuel
+v Mouvement Perpétuel
 
-3 rection du Surmle
-4 St Andr Marcueil, ascte cycliste
+3 Érection du Surmâle
+4 St André Marcueil, ascète cycliste
 4 St Ellen, hile
-4 St Michet, idaliste
-4 St Ouducul, trouvre
+4 St Michet, idéaliste
+4 St Ouducul, trouvère
 4 Vers Belges
 4 St Gavroche, forain
-3 La Machine  Inspirer l'Amour
-4 St Remezy, vque in partibus
-4 Nativit de St Tancrde, jeune homme
-4 Testament de P. Uccello, le mal illumin
+3 La Machine à Inspirer l'Amour
+4 St Remezy, évêque in partibus
+4 Nativité de St Tancrède, jeune homme
+4 Testament de P. Uccello, le mal illuminé
 4 St Hari Seldon, psychohistorien galactique
 4 Ste Valburge, succube
 v Sabbat
-3 Sts Adelphes, sotristes
+3 Sts Adelphes, ésotéristes
 4 Sts Templiers, adeptes
-4 St Dricarpe, proslyte
+4 St Dricarpe, prosélyte
 4 St Nosocome, carabin
-4 Ste Goutte, fte militaire
+4 Ste Goutte, fête militaire
 4 Ste Cuisse, dame patronnesse
 4 St Inscrit, Converti
-2 St Sengle, dserteur
+2 St Sengle, déserteur
 4 St Masquarade, uniforme
-4 Nativit de St Stphane, faune
+4 Nativité de St Stéphane, faune
 4 St Poligraf Poligrafovitch, chien
-4 St Ple, mineur
-3 St Valens, frre onirique
-v Ddicace du Tripode
+4 St Pâle, mineur
+3 St Valens, frère onirique
+v Dédicace du Tripode
 4 Bse Escampette, dynamiteuse
 
 3 St Ablou, page et St Haldern, duc
-4 Sts Hiboux, matres-chanteurs
-4 La Mandragore, solane androde
+4 Sts Hiboux, maîtres-chanteurs
+4 La Mandragore, solanée androïde
 4 St Pagne, confident
-4 Sts Aster et Vulpian, violateurs du Nant
-4 St Ganymde, professionnel
+4 Sts Aster et Vulpian, violateurs du Néant
+4 St Ganymède, professionnel
 v La Main de Gloire
-3 La Machine  Peindre
+3 La Machine à Peindre
 4 Ste Trique, lunatique
-4 Rmission des Poissons
+4 Rémission des Poissons
 4 St Maquereau, intercesseur
 4 St Georges Dazet, poulpe au regard de soie
-4 Nativit de Maldoror, corsaire aux cheveux d'or
-4 Sortie d'A. Drer, hermtiste
+4 Nativité de Maldoror, corsaire aux cheveux d'or
+4 Sortie d'A. Dürer, hermétiste
 * Invention de la 'Pataphysique
 4 Exit St Domenico Theotocopouli, el Greco
-4 St Hironymus Bosch, dmonarque
-v Les 27 tres Issus des Livres Pairs
+4 St Hiéronymus Bosch, démonarque
+v Les 27 Êtres Issus des Livres Pairs
 4 St Barbeau, procureur et Ste Morue, juste
 v Capture du Fourneau
 4 St Docteur Moreau, insulaire
-2 Fte des Polydres
+2 Fête des Polyèdres
 v Locus Solus
 4 St Tupetu de Tupetu, organisateur de loteries
 4 Exit St Goya, alchimiste
 4 St Escargot, sybarite
-4 Ste Hure de Chastet, pnitente
+4 Ste Hure de Chasteté, pénitente
 4 St Turgescent, iconoclaste
 v Cymbalum Mundi
 
 3 Sts Crocodiles, crocodiles
-4 Fte des cluses
+4 Fête des Écluses
 4 Sts Trolls, pantins
 4 Ste Susan Calvin, docteur
-4 Ste Poigne, veuve et Ste Jutte, recluse
+4 Ste Poignée, veuve et Ste Jutte, recluse
 4 Ste Oneille, gourgandine
-4 St Fnon s Liens
+4 St Fénéon ès Liens
 3 St Bougrelas, prince
 4 Sts Boleslas et Ladislas, polonais
 4 St Forficule, Barnabite
 v Explosion du Palotin
-v Rprobation du Travail
-4 Esquive de St Lonard (de Vinci), illusionniste
-4 St quivoque, sans-culotte
+v Réprobation du Travail
+4 Esquive de St Léonard (de Vinci), illusionniste
+4 St Équivoque, sans-culotte
 3 Adoration du Pal
-4 Dploration de St Achras, leveur de Polydres
+4 Déploration de St Achras, éleveur de Polyèdres
 4 St Macrotatoure, caudataire
 v Canotage
-4 Occultation de St Gauguin, ocanide
-4 St Ti Belot, side
+4 Occultation de St Gauguin, océanide
+4 St Ti Belot, séide
 4 Occultation de Sa Magnificence le Dr Sandomir
 2 Sts Palotins des Phynances
 4 Sts Quatrezoneilles, Herdanpo, Mousched-Gogh, palotins
-4 Ste Lumelle, cuyre
+4 Ste Lumelle, écuyère
 4 Sts Potassons, acolythes
-4 Ste Prtentaine, rosire
-4 St Foin, coryphe
-4 Nativit de St Satie, Grand Parcier de l'glise d'Art
+4 Ste Prétentaine, rosière
+4 St Foin, coryphée
+4 Nativité de St Satie, Grand Parcier de l'Église d'Art
 v Erratum
 
 3 Accouchement de Ste Jeanne, papesse
 v Le Moutardier du Pape
-4 St Sige, sous-pape
-4 Nativit de St H. Rousseau, douanier
+4 St Siège, sous-pape
+4 Nativité de St H. Rousseau, douanier
 4 St Crouducul, troupier
-4 St Cucufat, mcne
-4 Nativit de M. Plume, propritaire
+4 St Cucufat, mécène
+4 Nativité de M. Plume, propriétaire
 2 Cocuage de M. le P. Ubu
 v Vidange
 4 St Barbapoux, amant
 4 St Memnon, vidangeur
-4 Stes Miches, catchumnes
+4 Stes Miches, catéchumènes
 4 Ste Lunette, solitaire
-4 St Sphincter, profs
+4 St Sphincter, profès
 3 Sts Serpents d'Airain
-4 Nativit de St Donatien A. Franois
+4 Nativité de St Donatien A. François
 4 St Woland, professeur
 4 St Anal, cordelier et Ste Foire, anagogue
-4 Ste Ftatoire, super
-4 Ste Colombine, expurge
-4 Ste Pyrotechnie, illumine
-* Ontognie Pataphysique
-3 Interprtation de L'Umour
+4 Ste Fétatoire, super
+4 Ste Colombine, expurgée
+4 Ste Pyrotechnie, illuminée
+* Ontogénie Pataphysique
+3 Interprétation de L'Umour
 4 Ste Purge, sage-femme
 2 Apparition D'Ubu Roi
-4 Ste Barbaque, naade
+4 Ste Barbaque, naïade
 4 Sts Courts et Longs, gendarmes
 4 St Raca, cagot
-v Dfaite du Mufle
+v Défaite du Mufle
 
 3 Ste Bouzine, esprit
 4 St Lucullus, amateur (Bloomsday)
 4 Ste Dondon, amazone
-4 Ste Tripe, rpublicaine
+4 Ste Tripe, républicaine
 4 St Ugolin, mansuet
-4 St Dieu, retrait
-4 St Bb Toutout, vangliste
-3 Ste Boudouille, bayadre
+4 St Dieu, retraité
+4 St Bébé Toutout, évangéliste
+3 Ste Boudouille, bayadère
 4 Ste Outre, psychiatre
 4 St Boudin, recteur
-4 Sacre de Talou VII, empereur du Ponukl
-4 Ste Confiture, dvote et Ste Cliche, donatrice
+4 Sacre de Talou VII, empereur du Ponukélé
+4 Ste Confiture, dévote et Ste Cliche, donatrice
 4 Sts Instintestins, conseillers intimes
 4 St Colon, artilleur
-3 Ste Giborgne, vnrable
-4 St Inventaire, pote
+3 Ste Giborgne, vénérable
+4 St Inventaire, poète
 4 Ste Femelle, technicienne
-2 Visitation de Mre Ubu
+2 Visitation de Mère Ubu
 4 St Sein, tautologue
-4 St Prine, zlateur
-4 St Spculum, confesseur
-2 Fte de Gidouille
+4 St Périnée, zélateur
+4 St Spéculum, confesseur
+2 Fête de Gidouille
 4 St Ombilic, gymnosophiste
 4 St Gris-gris, ventre
 4 St Bouffre, pontife
 4 Ste Goulache, odalisque
-4 Ste Gandouse, hyginiste
-v Poche du Pre Ubu
+4 Ste Gandouse, hygiéniste
+v Poche du Père Ubu
 2 Nom d'Ubu
 
-1 Fte du P. Ubu (Ubu d't)
-4 Commmoration du P. b
+1 Fête du P. Ubu (Ubu d'été)
+4 Commémoration du P. Ébé
 4 Ste Crapule, puriste et St Fantomas, archange
 4 Ascension du Mouchard, statisticien, psychiatre et policier
 4 St Arsouille, patricien
 4 Sts Robot et Cornard, citoyens
 4 St Biribi, taulier
-2 Susception du Croc  Merdre
-4 Sts crase-Merdre, sectateurs
-4 Sts Pieds Nickels, trinit
+2 Susception du Croc à Merdre
+4 Sts Écrase-Merdre, sectateurs
+4 Sts Pieds Nickelés, trinité
 4 Stes Canicule et Canule, jouvencelles
 4 Sts Cannibales, philanthropes
-4 St Dada, prophte
-4 Ste Anne, plerine, nergumne
+4 St Dada, prophète
+4 Ste Anne, pèlerine, énergumène
 2 Procession aux Phynances
 4 Transfiguration de St V. van Gogh, transmutateur
 4 Ste Flamberge, voyante
 4 St Trou, chauffeur
 4 Ste Taloche, matrone
-4 St Tiberge, frre quteur
+4 St Tiberge, frère quêteur
 4 Sts Catoblepas, lord et Anoblepas, amiral
-2 Ubu s Liens
+2 Ubu ès Liens
 4 St Pissembock, oncle
 4 St Pissedoux, caporal des hommes libres
 4 St Panurge, moraliste
-4 St Gl, neurologue-aliniste
-4 St Pistolet  Merdre, jubilaire
-4 Nativit de St Bruggle
+4 St Glé, neurologue-aliéniste
+4 St Pistolet à Merdre, jubilaire
+4 Nativité de St Bruggle
 v Le soleil solide froid
 
 3 St Chibre, planton
-4 Ste Ruth, zlatrice
+4 Ste Ruth, zélatrice
 4 St Zebb, passe-partout
 4 St Mnester, confesseur
 2 Assomption de Ste Messaline
 v Penis Angelicus
 4 St Patrobas, pompier
-3 Ste Lda, ajusteuse
-4 St Godemich, conome
+3 Ste Léda, ajusteuse
+4 St Godemiché, économe
 4 Ste Nitouche, orante
-4 Ste Lchefrite, botteuse
+4 Ste Lèchefrite, botteuse
 4 Ste Andouille, amphibologue
-4 Ste Bitre, ouvreuse et St talon, couvreur
+4 Ste Bitre, ouvreuse et St Étalon, couvreur
 3 Bataille de Morsang
 3 Mort de Dionysos, surhomme
-4 Nativit de St Vibescu, pohte et Commmoration de Ste Cuculine d'Ancne
-4 Ste Gallinace, cocotte
+4 Nativité de St Vibescu, pohète et Commémoration de Ste Cuculine d'Ancône
+4 Ste Gallinacée, cocotte
 4 St Lingam, bouche-trou
-4 St Prlote, capucin
+4 St Prélote, capucin
 4 St Pie VIII, navigant
 3 St Erbrand, polytechnicien
 2 Ste Dragonne, pyrophage
 4 St Lazare, gare
-4 Ste Orchide, aumonire
-4 Nativit apparente d'Artaud le Momo
+4 Ste Orchidée, aumonière
+4 Nativité apparente d'Artaud le Momo
 4 Disparition de l'Ancien Breughel, incendiaire
 4 St Priape, franc-tireur
 3 Transfixion de Ste Messaline
-v Le Terms
+v Le Termès
 EOF
 
 1;
@@ -925,6 +923,20 @@ sub add_duration {
 1;
 __END__
 
+=for Pod::Coverage::TrustPod
+     DefaultLocale
+     day_0
+     day_of_month_0
+     day_of_week_0
+     day_of_year_0
+     locale
+     mday_0
+     mon
+     mon_0
+     month_0
+
+=encoding utf-8
+
 =head1 NAME
 
 DateTime::Calendar::Pataphysical - Dates in the pataphysical calendar
@@ -946,7 +958,7 @@ irregular Gregorian calendar.
 
 This module is designed to be easy to use in combination with
 DateTime. Most of its methods correspond to a DateTime method of the
-same name. 
+same name.
 
 =head1 METHODS
 
@@ -1097,11 +1109,11 @@ Returns the feast or vacuation of the given date.
 
 Returns the type of feast or vacuation.
 
-  '*' means Fte Suprme Premire premire
-  '1' means Fte Suprme Premire seconde
-  '2' means Fte Suprme Seconde
-  '3' means Fte Suprme Tierce
-  '4' means Fte Suprme Quarte
+  '*' means Fête Suprème Première première
+  '1' means Fête Suprème Première seconde
+  '2' means Fête Suprème Seconde
+  '3' means Fête Suprème Tierce
+  '4' means Fête Suprème Quarte
   'v' means Vacuation
 
 =item * is_imaginary
